@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::GenPericmdScript;
 
-our $DATE = '2015-09-15'; # DATE
-our $VERSION = '0.26'; # VERSION
+our $DATE = '2015-10-13'; # DATE
+our $VERSION = '0.27'; # VERSION
 
 use 5.010001;
 use strict;
@@ -19,7 +19,7 @@ with (
 
 use namespace::autoclean;
 
-use App::GenPericmdScript qw(gen_perinci_cmdline_script);
+use Perinci::CmdLine::Gen qw(gen_pericmd_script);
 use Module::Load;
 
 has build_load_modules => (is=>'rw');
@@ -124,7 +124,7 @@ sub munge_files {
         my $code_after_end = $self->code_after_end;
         if (ref($code_after_end) eq 'ARRAY') { $code_after_end = join("\n", @$code_after_end) }
 
-        $res = gen_perinci_cmdline_script(
+        $res = gen_pericmd_script(
             url => $self->url,
             script_name => $scriptname,
             script_version => $self->zilla->version,
@@ -226,7 +226,7 @@ Dist::Zilla::Plugin::GenPericmdScript - Generate Perinci::CmdLine script
 
 =head1 VERSION
 
-This document describes version 0.26 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2015-09-15.
+This document describes version 0.27 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2015-10-13.
 
 =head1 SYNOPSIS
 
@@ -404,7 +404,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-GenPericmdScript>.
+Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-Rinci-ScriptFromFunc>.
 
 =head1 BUGS
 
